@@ -3,8 +3,8 @@ import time
 
 import pytest
 
-from aiovk2.drivers import BaseDriver
-from aiovk2.mixins import LimitRateDriverMixin
+from aiovk.drivers import BaseDriver
+from aiovk.mixins import LimitRateDriverMixin
 
 pytestmark = pytest.mark.asyncio
 
@@ -36,4 +36,4 @@ async def test_request_shaper_mixin(period, requests_per_period, rps, lower, upp
     data = await asyncio.gather(*(driver.post_json() for _ in range(rps)))
     await driver.close()
     max_time = max(v[1] for v in data)
-    assert lower <= max_time - t0 <= upper
+    assert lower < max_time - t0 < upper
